==> kubernetes-model-0.1.5-sources.jar: annotations/io/fabric8/kubernetes/api/model/NodeSystemInfoBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class NodeSystemInfoBuilder extends NodeSystemInfoFluent<NodeSystemInfoBuilder> implements VisitableBuilder<NodeSystemInfo,NodeSystemInfoBuilder>{

     NodeSystemInfoFluent<?> fluent;
public NodeSystemInfoBuilder(){
    this(new NodeSystemInfo());
}
public NodeSystemInfoBuilder( NodeSystemInfoFluent<?> fluent ){
    this(fluent, new NodeSystemInfo());
}
public NodeSystemInfoBuilder( NodeSystemInfoFluent<?> fluent , NodeSystemInfo instance ){
    this.fluent = fluent; fluent.withBootID(instance.getBootID()); fluent.withContainerRuntimeVersion(instance.getContainerRuntimeVersion()); fluent.withKernelVersion(instance.getKernelVersion()); fluent.withKubeProxyVersion(instance.getKubeProxyVersion()); fluent.withKubeletVersion(instance.getKubeletVersion()); fluent.withMachineID(instance.getMachineID()); fluent.withOsImage(instance.getOsImage()); fluent.withSystemUUID(instance.getSystemUUID()); 
}
public NodeSystemInfoBuilder( NodeSystemInfo instance ){
    this.fluent = this; this.withBootID(instance.getBootID()); this.withContainerRuntimeVersion(instance.getContainerRuntimeVersion()); this.withKernelVersion(instance.getKernelVersion()); this.withKubeProxyVersion(instance.getKubeProxyVersion()); this.withKubeletVersion(instance.getKubeletVersion()); this.withMachineID(instance.getMachineID()); this.withOsImage(instance.getOsImage()); this.withSystemUUID(instance.getSystemUUID()); 
}

public EditableNodeSystemInfo build(){
    EditableNodeSystemInfo buildable = new EditableNodeSystemInfo(fluent.getBootID(),fluent.getContainerRuntimeVersion(),fluent.getKernelVersion(),fluent.getKubeProxyVersion(),fluent.getKubeletVersion(),fluent.getMachineID(),fluent.getOsImage(),fluent.getSystemUUID());
validate(buildable);
return buildable;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.7-sources.jar: annotations/io/fabric8/kubernetes/api/model/NodeSystemInfoBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class NodeSystemInfoBuilder extends NodeSystemInfoFluent<NodeSystemInfoBuilder> implements VisitableBuilder<NodeSystemInfo,NodeSystemInfoBuilder>{

     NodeSystemInfoFluent<?> fluent;
public NodeSystemInfoBuilder(){
    this(new NodeSystemInfo());
}
public NodeSystemInfoBuilder( NodeSystemInfoFluent<?> fluent ){
    this(fluent, new NodeSystemInfo());
}
public NodeSystemInfoBuilder( NodeSystemInfoFluent<?> fluent , NodeSystemInfo instance ){
    this.fluent = fluent; fluent.withBootID(instance.getBootID()); fluent.withContainerRuntimeVersion(instance.getContainerRuntimeVersion()); fluent.withKernelVersion(instance.getKernelVersion()); fluent.withKubeProxyVersion(instance.getKubeProxyVersion()); fluent.withKubeletVersion(instance.getKubeletVersion()); fluent.withMachineID(instance.getMachineID()); fluent.withOsImage(instance.getOsImage()); fluent.withSystemUUID(instance.getSystemUUID()); 
}
public NodeSystemInfoBuilder( NodeSystemInfo instance ){
    this.fluent = this; this.withBootID(instance.getBootID()); this.withContainerRuntimeVersion(instance.getContainerRuntimeVersion()); this.withKernelVersion(instance.getKernelVersion()); this.withKubeProxyVersion(instance.getKubeProxyVersion()); this.withKubeletVersion(instance.getKubeletVersion()); this.withMachineID(instance.getMachineID()); this.withOsImage(instance.getOsImage()); this.withSystemUUID(instance.getSystemUUID()); 
}

public EditableNodeSystemInfo build(){
    EditableNodeSystemInfo buildable = new EditableNodeSystemInfo(fluent.getBootID(),fluent.getContainerRuntimeVersion(),fluent.getKernelVersion(),fluent.getKubeProxyVersion(),fluent.getKubeletVersion(),fluent.getMachineID(),fluent.getOsImage(),fluent.getSystemUUID());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NodeSystemInfoBuilder that = (NodeSystemInfoBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
